==> ejc-settlementmanage-impl-3.0.0-20221202.092227-124-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementFinalizedEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 总包结算定案会签表-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_finalized")
public class SettlementFinalizedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="developer")
    private java.lang.String developer; // 发包人
    @TableField(value="cost")
    private java.math.BigDecimal cost; // 成本(不含上缴)
    @TableField(value="structure_type")
    private java.lang.String structureType; // 结构类型
    @TableField(value="contract_scope")
    private java.lang.String contractScope; // 承包范围
    @TableField(value="construction_area")
    private java.lang.Double constructionArea; // 建筑面积
    @TableField(value="settlement_value")
    private java.math.BigDecimal settlementValue; // 结算值
    @TableField(value="latest_deadline")
    private java.util.Date latestDeadline; // 审批最迟期限
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="developer_id")
    private java.lang.Long developerId; // 发包人id
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value = "business_date")
    private Date businessDate; //业务日期


    public Date getBusinessDate() {
        return businessDate;
    }

    public void setBusinessDate(Date businessDate) {
        this.businessDate = businessDate;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 发包人
     */
    public java.lang.String getDeveloper() {
        return developer;
    }

    /**
     * 发包人
     */
    public void setDeveloper(java.lang.String developer) {
        this.developer = developer;
    }
    /**
     * 成本(不含上缴)
     */
    public java.math.BigDecimal getCost() {
        return cost;
    }

    /**
     * 成本(不含上缴)
     */
    public void setCost(java.math.BigDecimal cost) {
        this.cost = cost;
    }
    /**
     * 结构类型
     */
    public java.lang.String getStructureType() {
        return structureType;
    }

    /**
     * 结构类型
     */
    public void setStructureType(java.lang.String structureType) {
        this.structureType = structureType;
    }
    /**
     * 承包范围
     */
    public java.lang.String getContractScope() {
        return contractScope;
    }

    /**
     * 承包范围
     */
    public void setContractScope(java.lang.String contractScope) {
        this.contractScope = contractScope;
    }
    /**
     * 建筑面积
     */
    public java.lang.Double getConstructionArea() {
        return constructionArea;
    }

    /**
     * 建筑面积
     */
    public void setConstructionArea(java.lang.Double constructionArea) {
        this.constructionArea = constructionArea;
    }
    /**
     * 结算值
     */
    public java.math.BigDecimal getSettlementValue() {
        return settlementValue;
    }

    /**
     * 结算值
     */
    public void setSettlementValue(java.math.BigDecimal settlementValue) {
        this.settlementValue = settlementValue;
    }
    /**
     * 审批最迟期限
     */
    public java.util.Date getLatestDeadline() {
        return latestDeadline;
    }

    /**
     * 审批最迟期限
     */
    public void setLatestDeadline(java.util.Date latestDeadline) {
        this.latestDeadline = latestDeadline;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 发包人id
     */
    public java.lang.Long getDeveloperId() {
        return developerId;
    }

    /**
     * 发包人id
     */
    public void setDeveloperId(java.lang.Long developerId) {
        this.developerId = developerId;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230106.104258-162-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementFinalizedEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 总包结算定案会签表-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_finalized")
public class SettlementFinalizedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="developer")
    private java.lang.String developer; // 发包人
    @TableField(value="profit")
    private java.math.BigDecimal profit; // 利润
    @TableField(value="cost")
    private java.math.BigDecimal cost; // 成本(不含上缴)
    @TableField(value="profit_rate")
    private java.math.BigDecimal profitRate; // 利润率
    @TableField(value="structure_type")
    private java.lang.String structureType; // 结构类型
    @TableField(value="contract_scope")
    private java.lang.String contractScope; // 承包范围
    @TableField(value="construction_area")
    private java.lang.String constructionArea; // 建筑面积
    @TableField(value="settlement_value")
    private java.math.BigDecimal settlementValue; // 结算值
    @TableField(value="latest_deadline")
    private java.util.Date latestDeadline; // 审批最迟期限
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人id
    @TableField(value="agent_department")
    private java.lang.Long agentDepartment; // 经办人部门
    @TableField(value="contract_id")
    private java.lang.Long contractId; // 合同id
    @TableField(value="developer_id")
    private java.lang.Long developerId; // 发包人id
    @TableField(value = "original_id")
    private java.lang.Long originalId;
    @TableField(value = "business_date")
    private Date businessDate; //业务日期


    public Date getBusinessDate() {
        return businessDate;
    }

    public void setBusinessDate(Date businessDate) {
        this.businessDate = businessDate;
    }

    public BigDecimal getProfit() {
        return profit;
    }

    public void setProfit(BigDecimal profit) {
        this.profit = profit;
    }

    public BigDecimal getProfitRate() {
        return profitRate;
    }

    public void setProfitRate(BigDecimal profitRate) {
        this.profitRate = profitRate;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 发包人
     */
    public java.lang.String getDeveloper() {
        return developer;
    }

    /**
     * 发包人
     */
    public void setDeveloper(java.lang.String developer) {
        this.developer = developer;
    }
    /**
     * 成本(不含上缴)
     */
    public java.math.BigDecimal getCost() {
        return cost;
    }

    /**
     * 成本(不含上缴)
     */
    public void setCost(java.math.BigDecimal cost) {
        this.cost = cost;
    }
    /**
     * 结构类型
     */
    public java.lang.String getStructureType() {
        return structureType;
    }

    /**
     * 结构类型
     */
    public void setStructureType(java.lang.String structureType) {
        this.structureType = structureType;
    }
    /**
     * 承包范围
     */
    public java.lang.String getContractScope() {
        return contractScope;
    }

    /**
     * 承包范围
     */
    public void setContractScope(java.lang.String contractScope) {
        this.contractScope = contractScope;
    }
    /**
     * 建筑面积
     */
    public String getConstructionArea() {
        return constructionArea;
    }

    public void setConstructionArea(String constructionArea) {
        this.constructionArea = constructionArea;
    }

    /**
     * 结算值
     */
    public java.math.BigDecimal getSettlementValue() {
        return settlementValue;
    }

    /**
     * 结算值
     */
    public void setSettlementValue(java.math.BigDecimal settlementValue) {
        this.settlementValue = settlementValue;
    }
    /**
     * 审批最迟期限
     */
    public java.util.Date getLatestDeadline() {
        return latestDeadline;
    }

    /**
     * 审批最迟期限
     */
    public void setLatestDeadline(java.util.Date latestDeadline) {
        this.latestDeadline = latestDeadline;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人部门
     */
    public java.lang.Long getAgentDepartment() {
        return agentDepartment;
    }

    /**
     * 经办人部门
     */
    public void setAgentDepartment(java.lang.Long agentDepartment) {
        this.agentDepartment = agentDepartment;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 发包人id
     */
    public java.lang.Long getDeveloperId() {
        return developerId;
    }

    /**
     * 发包人id
     */
    public void setDeveloperId(java.lang.Long developerId) {
        this.developerId = developerId;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
